//
// SecureImage
//
// Copyright © 2018 Province of British Columbia
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// Created by Jason Leach on 2018-01-10.
//

/* eslint-disable no-console */
'use strict';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.started = exports.logger = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _ip = _interopRequireDefault(require("ip"));

var _winston = _interopRequireDefault(require("winston"));

var _constants = require("../constants");

const options = {};
const {
  combine,
  timestamp,
  printf
} = _winston.default.format;

const divider = _chalk.default.gray('\n-----------------------------------');

const myFormat = printf(info => `${info.timestamp} ${info.level}: ${info.message}`);
options.transports = [new _winston.default.transports.Console({
  format: combine(timestamp(), myFormat)
})];
/**
 * Re-export logger object
 *
 */

const logger = _winston.default.createLogger(options);
/**
 * Print canned message when the server starts
 *
 * @param {String} port The port the server is running on
 */


exports.logger = logger;

const started = (port, appName) => {
  console.log(`${_chalk.default.cyan(appName)} API started ${_chalk.default.green('✓')}`);
  console.log(`${_chalk.default.bold('\nAccess URLs:')}${divider}
               \nLocalhost: ${_chalk.default.magenta(`http://localhost:${port}`)}
               \r      LAN: ${_chalk.default.magenta(`http://${_ip.default.address()}:${port}`)}
               ${divider}`);

  if (process.env.NODE_ENV === _constants.ENVIRONMENTS.DEVELOPMENT) {
    console.log(`${_chalk.default.blue(`\nPress ${_chalk.default.italic('CTRL-C')} to stop\n`)}`);
  }
};

exports.started = started;